# -*- coding: utf-8 -*-

"""
 (c) 2019 - Copyright Red Hat Inc

 Authors:
   Pierre-Yves Chibon <pingou@pingoured.fr>

"""

from __future__ import unicode_literals, print_function

import logging
import sqlalchemy as sa

from sqlalchemy.orm import backref
from sqlalchemy.orm import relation

from pagure.lib.model_base import BASE
from pagure.lib.model import Project


_log = logging.getLogger(__name__)


# DB Model


class PagureAnitya(BASE):
    """ Stores information about the monitoring of a project in anitya.

    Table -- pagure_anitya
    """

    __tablename__ = "pagure_anitya"

    id = sa.Column(sa.Integer, primary_key=True)
    project_id = sa.Column(
        sa.Integer,
        sa.ForeignKey("projects.id", onupdate="CASCADE", ondelete="CASCADE"),
        nullable=False,
        unique=True,
        index=True,
    )

    anitya_status = sa.Column(
        sa.String(255), nullable=False, unique=False, default="no-monitoring"
    )

    project = relation(
        "Project",
        remote_side=[Project.id],
        backref=backref(
            "anitya",
            cascade="delete, delete-orphan",
            single_parent=True,
            uselist=False,
        ),
    )
